@@ -1,6 +1,6 @@
 ## Domain Registry Interface, EPP Protocol (STD 69)
 ##
-## Copyright (c) 2005-2011,2013-2014 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2005-2011,2013-2014,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -17,6 +17,7 @@ package Net::DRI::Protocol::EPP;
 use utf8;
 use strict;
 use warnings;
+use version 0.77;
 
 use base qw(Net::DRI::Protocol);
 
@@ -52,7 +53,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2005-2011,2013-2014 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2005-2011,2013-2014,2016 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -140,7 +141,9 @@ sub switch_to_highest_namespace_version
 {
  my ($self,$nsalias)=@_;
 
- my ($basens)=($self->message()->ns($nsalias)=~m/^(\S+)-[\d.]+$/);
+ my $ns=$self->message()->ns($nsalias);
+ Net::DRI::Exception::err_invalid_parameters("No namespace defined for alias \"$nsalias\"") unless defined $ns;
+ my ($basens)=($ns=~m/^(\S+)-[\d.]+$/);
  my $rs=$self->default_parameters()->{server};
  my @ns=grep { m/^${basens}-\S+$/ } @{$rs->{extensions_selected}};
  Net::DRI::Exception::err_invalid_parameters("No extension found under namespace ${basens}-*") unless @ns;
@@ -149,7 +152,7 @@ sub switch_to_highest_namespace_version
  foreach my $ns (@ns)
  {
   my ($v)=($ns=~m/^\S+-([\d.]+)$/);
-  $version=0+$v if ! defined $version || 0+$v > $version;
+  $version=0+$v if ! defined $version || version->parse('v'.(0+$v)) > version->parse('v'.$version); ## needed for fees (fees-0.4 fees-0.7 fees-0.11 etc...)
  }
 
  my $fullns=$basens.'-'.$version;
