@@ -1,7 +1,7 @@
 ## Domain Registry Interface, ENUM.AT Options extension
 ## Contributed by Michael Braunoeder from ENUM.AT <michael.braunoeder@enum.at>
 ##
-## Copyright (c) 2006,2008,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006,2008,2013,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -20,8 +20,7 @@ use warnings;
 
 use Net::DRI::Util;
 use Net::DRI::Exception;
-
-our $NS='http://www.enum.at/rxsd/ienum43-options-1.0';
+use feature 'state';
 
 =pod
 
@@ -51,7 +50,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006,2008,2013,2016 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -77,6 +76,15 @@ sub register_commands
  return { 'domain' => \%tmp };
 }
 
+sub setup
+{
+ my ($class,$po,$version)=@_;
+ state $ns = { 'ienum43' => [ 'http://www.enum.at/rxsd/ienum43-options-1.0', 'ienum43-options-1.0.xsd' ],
+             };
+ $po->ns($ns);
+ return;
+}
+
 sub capabilities_add { return ('domain_update','options',['set']); }
 
 sub parse_options
@@ -84,12 +92,12 @@ sub parse_options
  my ($po,$otype,$oaction,$oname,$rinfo)=@_;
  my $mes=$po->message();
 
- my $condata=$mes->get_extension($NS,'options');
+ my $condata=$mes->get_extension('ienum43','options');
  return unless $condata;
 
  my @options;
 
- foreach my $el ($condata->getElementsByTagNameNS($NS,'naptr-application'))
+ foreach my $el ($condata->getElementsByTagNameNS($mes->ns('ienum43'),'naptr-application'))
  {
   my %opts;
   my $c=$el->getFirstChild();
@@ -122,7 +130,7 @@ sub set_options
 
  return unless keys(%options);
 
- my $eid=$mes->command_extension_register('ienum43:update','xmlns:ienum43="'.$NS.'" xsi:schemaLocation="'.$NS.' ienum43-options-1.0.xsd"');
+ my $eid=$mes->command_extension_register('ienum43','update');
  $mes->command_extension($eid,[['ienum43:options',['ienum43:naptr-application',\%options]]]);
  return;
 }
