@@ -2,6 +2,7 @@
 ## (introduced in release 5.6 october 2008)
 ##
 ## Copyright (c) 2009,2012-2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+##               2014 Michael Kefeder <michael.kefeder@world4you.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -49,6 +50,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 =head1 COPYRIGHT
 
 Copyright (c) 2009,2012-2013 Patrick Mevzek <netdri@dotandco.com>.
+              2014 Michael Kefeder <michael.kefeder@world4you.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -75,7 +77,7 @@ sub register_commands
 sub setup
 {
  my ($class,$po,$version)=@_;
- $po->ns({ 'poll' => [ 'http://www.eurid.eu/xml/epp/poll-1.0','poll-1.0.xsd' ] });
+ $po->ns({ 'poll' => [ 'http://www.eurid.eu/xml/epp/poll-1.1','poll-1.1.xsd' ] });
  return;
 }
 
@@ -94,7 +96,7 @@ sub parse
  foreach my $el (Net::DRI::Util::xml_list_children($poll))
  {
   my ($name,$c)=@$el;
-  if ($name=~m/^(context|object|action|code|detail)$/)
+  if ($name=~m/^(context|object|action|code|detail|objectType|objectUnicode)$/)
   {
    $n{$1}=$c->textContent();
   }
@@ -108,6 +110,8 @@ sub parse
   $rinfo->{domain}->{$oname}->{action}=$n{action};
   $rinfo->{domain}->{$oname}->{detail}=$n{detail} if exists $n{detail};
   $rinfo->{domain}->{$oname}->{context}=$n{context};
+  $rinfo->{domain}->{$oname}->{object_type}=$n{objectType};
+  $rinfo->{domain}->{$oname}->{object_unicode}=$n{objectUnicode};
   $rinfo->{domain}->{$oname}->{exist}=1;
  } else
  {
