@@ -1,4 +1,4 @@
-## Domain Registry Interface, Mark & Signed Mark for EPP
+## Domain Registry Interface, Mark & Signed Mark for EPP (RFC7848)
 ##
 ## Copyright (c) 2013-2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
@@ -36,7 +36,7 @@ sub setup
  return;
 }
 
-sub implements { return 'https://tools.ietf.org/html/draft-ietf-eppext-tmch-smd-06'; }
+sub implements { return 'https://tools.ietf.org/html/rfc7848'; }
 
 my %xml2perl = ( trademark       => 'trademark',
                  treatyOrStatute => 'treaty_statute',
@@ -645,7 +645,7 @@ __END__
 
 =head1 NAME
 
-Net::DRI::Protocol::EPP::Extensions::ICANN::MarkSignedMark - ICANN TMCH Mark/Signed Mark EPP Extension (draft-ietf-eppext-tmch-smd-06) for Net::DRI
+Net::DRI::Protocol::EPP::Extensions::ICANN::MarkSignedMark - ICANN TMCH Mark/Signed Mark EPP Extension (RFC 7848) for Net::DRI
 
 =head1 DESCRIPTION
 
