@@ -1,6 +1,6 @@
 ## Domain Registry Interface, EPP IDN Language (EPP-IDN-Lang-Mapping.pdf)
 ##
-## Copyright (c) 2006,2008,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+## Copyright (c) 2006,2008,2013,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -16,6 +16,7 @@ package Net::DRI::Protocol::EPP::Extensions::VeriSign::IDNLanguage;
 
 use strict;
 use warnings;
+use feature 'state';
 
 use Net::DRI::Util;
 use Net::DRI::Exception;
@@ -48,7 +49,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006,2008,2013 Patrick Mevzek <netdri@dotandco.com>.
+Copyright (c) 2006,2008,2013,2016 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -65,11 +66,17 @@ See the LICENSE file that comes with this distribution for more details.
 sub register_commands
 {
  my ($class,$version)=@_;
- my %tmp=(
-           create => [ \&create, undef ],
-         );
+ state $cmds = { 'domain' => { 'create' => [ \&create, undef ] } };
 
- return { 'domain' => \%tmp };
+ return $cmds;
+}
+
+sub setup
+{
+ my ($class,$po,$version)=@_;
+ state $rns = { 'idnLang' => [ 'http://www.verisign.com/epp/idnLang-1.0', 'idnLang-1.0.xsd' ] };
+ $po->ns($rns);
+ return;
 }
 
 ####################################################################################################
@@ -79,7 +86,6 @@ sub register_commands
 sub create
 {
  my ($epp,$domain,$rd)=@_;
- my $mes=$epp->message();
 
  return unless ($domain=~/^xn--/);
 
@@ -87,7 +93,8 @@ sub create
 
  Net::DRI::Exception::usererr_invalid_parameters('IDN language tag must be of type XML schema language') unless Net::DRI::Util::xml_is_language($rd->{language});
 
- my $eid=$mes->command_extension_register('idnLang:tag','xmlns:idnLang="http://www.verisign.com/epp/idnLang-1.0" xsi:schemaLocation="http://www.verisign.com/epp/idnLang-1.0 idnLang-1.0.xsd"');
+ my $mes=$epp->message();
+ my $eid=$mes->command_extension_register('idnLang', 'tag');
  $mes->command_extension($eid,$rd->{language});
  return;
 }
