@@ -1,7 +1,7 @@
 ## Domain Registry Interface, EPP NameStore Extension for Verisign
 ##
 ## Copyright (c) 2006,2008,2009 Rony Meyer <perl@spot-light.ch>. All rights reserved.
-##                    2010,2013 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
+##               2010,2013,2016 Patrick Mevzek <netdri@dotandco.com>. All rights reserved.
 ##
 ## This file is part of Net::DRI
 ##
@@ -17,11 +17,9 @@ package Net::DRI::Protocol::EPP::Extensions::VeriSign::NameStore;
 
 use strict;
 use warnings;
+use feature 'state';
 
 use Net::DRI::Util;
-use Net::DRI::Exception;
-
-our $NS='http://www.verisign-grs.com/epp/namestoreExt-1.1';
 
 =pod
 
@@ -53,7 +51,7 @@ Patrick Mevzek, E<lt>netdri@dotandco.comE<gt>
 =head1 COPYRIGHT
 
 Copyright (c) 2006,2008,2009 Rony Meyer <perl@spot-light.ch>.
-          (c) 2010,2013 Patrick Mevzek <netdri@dotandco.com>.
+          (c) 2010,2013,2016 Patrick Mevzek <netdri@dotandco.com>.
 All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
@@ -112,6 +110,14 @@ sub register_commands
         };
 }
 
+sub setup
+{
+ my ($class,$po,$version)=@_;
+ state $rns = { 'namestoreExt' => [ 'http://www.verisign-grs.com/epp/namestoreExt-1.1', 'namestoreExt-1.1.xsd' ] };
+ $po->ns($rns);
+ return;
+}
+
 ####################################################################################################
 
 ########### Add the NameStore Extenstion to all domain & host commands
@@ -123,7 +129,7 @@ sub add_namestore_ext
  my $mes=$epp->message();
  my $defprod=$epp->default_parameters()->{subproductid};
 
- my $eid=$mes->command_extension_register('namestoreExt:namestoreExt',sprintf('xmlns:namestoreExt="%s" xsi:schemaLocation="%s namestoreExt-1.1.xsd"',$NS,$NS));
+ my $eid=$mes->command_extension_register('namestoreExt','namestoreExt');
 
  if (Net::DRI::Util::has_key($rd,'subproductid') && $rd->{subproductid})
  {
@@ -140,11 +146,7 @@ sub add_namestore_ext
  ## We do not know what will happen in case of check_multi with multiple TLDs
  my $ext='dotCOM';
  $domain=$domain->[0] if (ref($domain) eq 'ARRAY');
- $ext='dotNET' if ($domain=~m/\.net$/i);
- $ext='dotCC' if ($domain=~m/\.cc$/i);
- $ext='dotTV' if ($domain=~m/\.tv$/i);
- $ext='dotBZ' if ($domain=~m/\.bz$/i);
- $ext='dotJOBS' if ($domain=~m/\.jobs$/i);
+ $ext='dot'.uc($1) if ($domain=~m/\.(net|cc|tv|bz|jobs|edu)$/i);
 
  $mes->command_extension($eid,['namestoreExt:subProduct',$ext]);
  return;
@@ -156,9 +158,9 @@ sub parse
  my $mes=$po->message();
  return unless $mes->is_success();
 
- my $infdata=$mes->get_extension($NS,'namestoreExt');
+ my $infdata=$mes->get_extension('namestoreExt','namestoreExt');
  return unless $infdata;
- my $c=$infdata->getChildrenByTagNameNS($NS,'subProduct');
+ my $c=$infdata->getChildrenByTagNameNS($mes->ns('namestoreExt'),'subProduct');
  return unless $c;
 
  $rinfo->{$otype}->{$oname}->{subproductid}=$c->get_node(1)->textContent();
@@ -173,9 +175,9 @@ sub parse_error
  ## Parse namestoreExt in case of errors
  return unless $mes->result_is('PARAMETER_VALUE_POLICY_ERROR') || $mes->result_is('COMMAND_SYNTAX_ERROR');
 
- my $data=$mes->get_extension($NS,'nsExtErrData');
+ my $data=$mes->get_extension('namestoreExt','nsExtErrData');
  return unless defined $data;
- $data=$data->getChildrenByTagNameNS($NS,'msg');
+ $data=$data->getChildrenByTagNameNS($mes->ns('namestoreExt'),'msg');
  return unless defined $data && $data->size();
  $data=$data->get_node(1);
 
